# COPR Ligenix's spec file for glpi-plugin-treeview
#
# Copyright (c) 2022-2023 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname treeview
%global glpi_min   10.0.0
%global glpi_max   10.1.0

Name:           glpi-plugin-%{pluginname}
Version:        1.10.2
Release:        1%{?dist}
Summary:        Plugin to browse through your inventory via a tree view in a panel located on the left side of the screen.

License:        GPLv2
URL:            https://github.com/pluginsGLPI/%{pluginname}

Source0:        https://github.com/pluginsGLPI/%{pluginname}/releases/download/%{version}/glpi-%{pluginname}-%{version}.tar.bz2

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif


%description
This plugin allows you to browse through your inventory via a tree view in a panel located on the left side of the screen.

You can browse the tree of your site to see the equipment.


%prep
%setup -q -c

grep "define('PLUGIN_TREEVIEW_M.._GLPI" %{pluginname}/setup.php

# remove unused files
rm    %{pluginname}/%{pluginname}.xml
rm    %{pluginname}/composer.json
rm -r %{pluginname}/vendor

# move doc files
mkdir docs
mv %{pluginname}/*.md              docs/
mv %{pluginname}/screenshots/      docs/
mv %{pluginname}/%{pluginname}.gif docs/
mv %{pluginname}/glpi_network.png  docs/

# Create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs/*
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/%{pluginname}.png
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/js
%{_datadir}/glpi/plugins/%{pluginname}/pics
# data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Fri Jul 07 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.10.2-1
- Version 1.10.2

* Thu Jun 22 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.10.1-1
- Version 1.10.1

* Wed May 03 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.10.1-2
- Move screenshots to docs

* Mon Aug 01 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.10.0-1
- Version 1.10.0 for GLPI 10.0.x

* Mon Aug 01 2022 Jean-Marc Liger <ligenix@iscp.fr> - 1.9.1-1
- Version 1.9.1 for GLPI 9.5.x
- Initial RPM based on Remi Collet previous GLPI plugins spec files
